@@ -57,8 +57,6 @@ static gboolean        gdaui_entry_wrapper_can_expand        (GdauiDataEntry *de
 static void            gdaui_entry_wrapper_set_editable      (GdauiDataEntry *de, gboolean editable);
 static gboolean        gdaui_entry_wrapper_get_editable      (GdauiDataEntry *de);
 static void            gdaui_entry_wrapper_grab_focus        (GdauiDataEntry *de);
-static void            gdaui_entry_wrapper_set_unknown_color (GdauiDataEntry *de, gdouble red, gdouble green,
-							      gdouble blue, gdouble alpha);
 
 /* properties */
 enum {
@@ -140,7 +138,6 @@ gdaui_entry_wrapper_data_entry_init (GdauiDataEntryIface *iface)
 	iface->set_editable = gdaui_entry_wrapper_set_editable;
 	iface->get_editable = gdaui_entry_wrapper_get_editable;
 	iface->grab_focus = gdaui_entry_wrapper_grab_focus;
-	iface->set_unknown_color = gdaui_entry_wrapper_set_unknown_color;
 }
 
 
@@ -243,7 +240,7 @@ gdaui_entry_wrapper_init (GdauiEntryWrapper *mgwrap)
 	mgwrap->priv->real_class = NULL;
 	mgwrap->priv->signals_blocked = 0;
 
-	mgwrap->priv->type = G_TYPE_INVALID;
+	mgwrap->priv->type = GDA_TYPE_NULL;
 	mgwrap->priv->value_ref = NULL;
 	mgwrap->priv->value_default = NULL;
 
@@ -427,6 +424,7 @@ gdaui_entry_wrapper_set_value_type (GdauiDataEntry *iface, GType type)
 
 	if (mgwrap->priv->type != type) {
 		GValue *value;
+		GdaDataHandler *dh;
 
 		if (mgwrap->priv->value_ref) {
 			gda_value_free (mgwrap->priv->value_ref);
@@ -441,6 +439,7 @@ gdaui_entry_wrapper_set_value_type (GdauiDataEntry *iface, GType type)
 		mgwrap->priv->value_default = gda_value_new_null ();
 
 		/* Set original value */
+		dh = gdaui_data_entry_get_handler (GDAUI_DATA_ENTRY (mgwrap));
 		value = gda_value_new_null ();
 		gdaui_entry_wrapper_set_ref_value (GDAUI_DATA_ENTRY (mgwrap), value);
  		gda_value_free (value);
@@ -477,8 +476,10 @@ gdaui_entry_wrapper_set_value (GdauiDataEntry *iface, const GValue *value)
 			mgwrap->priv->null_forced = TRUE;
 		else
 			mgwrap->priv->null_forced = FALSE;
+		gdaui_entry_shell_set_unknown ((GdauiEntryShell*) iface, FALSE);
 	}
 	else {
+		gdaui_entry_shell_set_unknown ((GdauiEntryShell*) iface, TRUE);
 		(*mgwrap->priv->real_class->real_set_value) (mgwrap, NULL);
 		mgwrap->priv->null_forced = TRUE;
 	}
@@ -494,10 +495,13 @@ gdaui_entry_wrapper_get_value (GdauiDataEntry *iface)
 {
 	GValue *value = NULL;
 	GdauiEntryWrapper *mgwrap;
+	GdaDataHandler *dh;
 
 	g_return_val_if_fail (GDAUI_IS_ENTRY_WRAPPER (iface), NULL);
 	mgwrap = (GdauiEntryWrapper*) iface;
 
+	dh = gdaui_entry_wrapper_get_handler (GDAUI_DATA_ENTRY (mgwrap));
+
 	if (mgwrap->priv->null_forced)
 		value = gda_value_new_null ();
 	else {
@@ -714,6 +718,8 @@ gdaui_entry_wrapper_set_attributes (GdauiDataEntry *iface, GdaValueAttribute att
 		g_warning ("Having an original value is not a write attribute on GdauiDataEntry!");
 
 	current = gdaui_data_entry_get_attributes (iface);
+	gdaui_entry_shell_set_unknown ((GdauiEntryShell*) iface,
+				       current & GDA_VALUE_ATTR_DATA_NON_VALID ? TRUE : FALSE);
 
 	if (signal_contents_changed) {
 		mgwrap->priv->contents_has_changed = FALSE;
@@ -884,10 +890,3 @@ gdaui_entry_wrapper_grab_focus (GdauiDataEntry *iface)
 			gtk_widget_grab_focus (mgwrap->priv->entry);
 	}
 }
-
-static void
-gdaui_entry_wrapper_set_unknown_color (GdauiDataEntry *de, gdouble red, gdouble green,
-				       gdouble blue, gdouble alpha)
-{
-	gdaui_entry_shell_set_ucolor (GDAUI_ENTRY_SHELL (de), red, green, blue, alpha);
-}
