@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009 - 2010 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  *
  * This library is free software; you can redistribute it and/or
@@ -728,11 +728,7 @@ visibility_notify_event (GtkWidget *text_view, G_GNUC_UNUSED GdkEventVisibility
 {
 	gint wx, wy, bx, by;
 
-#if GTK_CHECK_VERSION(2,18,0)
 	gdk_window_get_pointer (gtk_widget_get_window (text_view), &wx, &wy, NULL);
-#else
-	gdk_window_get_pointer (text_view->window, &wx, &wy, NULL);
-#endif
 	
 	gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (text_view), 
 					       GTK_TEXT_WINDOW_WIDGET,
@@ -757,11 +753,7 @@ motion_notify_event (GtkWidget *text_view, GdkEventMotion *event, GdauiCloud *cl
 	
 	set_cursor_if_appropriate (GTK_TEXT_VIEW (text_view), x, y, cloud);
 	
-#if GTK_CHECK_VERSION(2,18,0)
 	gdk_window_get_pointer (gtk_widget_get_window (text_view), NULL, NULL, NULL);
-#else
-	gdk_window_get_pointer (text_view->window, NULL, NULL, NULL);
-#endif
 	return FALSE;
 }
 
@@ -836,18 +828,18 @@ key_press_event (GtkWidget *text_view, GdkEventKey *event, GdauiCloud *cloud)
         GtkTextBuffer *buffer;
 
         switch (event->keyval) {
-        case GDK_Return:
-        case GDK_space:
-        case GDK_KP_Enter:
+        case GDK_KEY_Return:
+        case GDK_KEY_space:
+        case GDK_KEY_KP_Enter:
                 buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (text_view));
                 gtk_text_buffer_get_iter_at_mark (buffer, &iter,
                                                   gtk_text_buffer_get_insert (buffer));
                 follow_if_link (text_view, &iter, cloud);
 		return TRUE;
-	case GDK_Up:
-	case GDK_Down:
-	case GDK_Left:
-	case GDK_Right:
+	case GDK_KEY_Up:
+	case GDK_KEY_Down:
+	case GDK_KEY_Left:
+	case GDK_KEY_Right:
 		if ((cloud->priv->selection_mode == GTK_SELECTION_SINGLE) ||
 		    (cloud->priv->selection_mode == GTK_SELECTION_BROWSE)) {
 			GtkTextIter iter;
@@ -856,7 +848,7 @@ key_press_event (GtkWidget *text_view, GdkEventKey *event, GdauiCloud *cloud)
 				mark = gtk_text_buffer_get_insert (cloud->priv->tbuffer);
 				gtk_text_buffer_get_iter_at_mark (cloud->priv->tbuffer, &iter, mark);
 			}
-			else if ((event->keyval == GDK_Right) || (event->keyval == GDK_Down))
+			else if ((event->keyval == GDK_KEY_Right) || (event->keyval == GDK_KEY_Down))
 				gtk_text_buffer_get_start_iter (cloud->priv->tbuffer, &iter);
 			else
 				gtk_text_buffer_get_end_iter (cloud->priv->tbuffer, &iter);
@@ -867,22 +859,22 @@ key_press_event (GtkWidget *text_view, GdkEventKey *event, GdauiCloud *cloud)
 				GtkMovementStep mvt_type;
 				gint mvt_amount;
 				switch (event->keyval) {
-				case GDK_Up:
+				case GDK_KEY_Up:
 					done = ! gtk_text_view_backward_display_line ((GtkTextView*)cloud->priv->tview, &iter);
 					mvt_type = GTK_MOVEMENT_DISPLAY_LINES;
 					mvt_amount = -1;
 					break;
-				case GDK_Down:
+				case GDK_KEY_Down:
 					done = ! gtk_text_view_forward_display_line ((GtkTextView*)cloud->priv->tview, &iter);
 					mvt_type = GTK_MOVEMENT_DISPLAY_LINES;
 					mvt_amount = 1;
 					break;
-				case GDK_Left:
+				case GDK_KEY_Left:
 					done = ! gtk_text_iter_backward_char (&iter);
 					mvt_type = GTK_MOVEMENT_VISUAL_POSITIONS;
 					mvt_amount = -1;
 					break;
-				case GDK_Right:
+				case GDK_KEY_Right:
 					done = ! gtk_text_iter_forward_char (&iter);
 					mvt_type = GTK_MOVEMENT_VISUAL_POSITIONS;
 					mvt_amount = 1;
@@ -1088,7 +1080,7 @@ gdaui_cloud_create_filter_widget (GdauiCloud *cloud)
  * gdaui_cloud_set_weight_func:
  * @cloud: a #GdauiCloud widget
  * @func: (allow-none): a #GdauiCloudWeightFunc function which computes weights, or %NULL to unset
- * @data: (allow-none): a pointer to pass as last argument of @func each time it is called, or %NULL
+ * @data: (allow-none): a pointer to pass as last argument of @func each time it is called
  *
  * Specifies a function called by @cloud to compute each row's respective weight.
  *
