@@ -49,7 +49,6 @@ static GError *iter_validate_set_cb (GdaDataModelIter *iter, GdauiRawForm *form)
 static void iter_row_changed_cb (GdaDataModelIter *iter, gint row, GdauiRawForm *form);
 static void proxy_changed_cb (GdaDataProxy *proxy, GdauiRawForm *form);
 static void proxy_reset_cb (GdaDataProxy *proxy, GdauiRawForm *form);
-static void proxy_access_changed_cb (GdaDataProxy *proxy, GdauiRawForm *form);
 static void proxy_row_inserted_or_removed_cb (GdaDataProxy *proxy, gint row, GdauiRawForm *form);
 
 /* GdauiDataProxy interface */
@@ -185,7 +184,8 @@ gdaui_raw_form_class_init (GdauiRawFormClass *class)
 }
 
 static void action_new_cb (GtkAction *action, GdauiRawForm *form);
-static void action_delete_cb (GtkToggleAction *action, GdauiRawForm *form);
+static void action_delete_cb (GtkAction *action, GdauiRawForm *form);
+static void action_undelete_cb (GtkAction *action, GdauiRawForm *form);
 static void action_commit_cb (GtkAction *action, GdauiRawForm *form);
 static void action_reset_cb (GtkAction *action, GdauiRawForm *form);
 static void action_first_record_cb (GtkAction *action, GdauiRawForm *form);
@@ -194,19 +194,23 @@ static void action_next_record_cb (GtkAction *action, GdauiRawForm *form);
 static void action_last_record_cb (GtkAction *action, GdauiRawForm *form);
 static void action_filter_cb (GtkAction *action, GdauiRawForm *form);
 
-static GtkToggleActionEntry ui_actions_t[] = {
-	{ "ActionDelete", GTK_STOCK_REMOVE, "_Delete", NULL, N_("Delete the current record"), G_CALLBACK (action_delete_cb), FALSE},
-};
-
 static GtkActionEntry ui_actions[] = {
-	{ "ActionNew", GTK_STOCK_ADD, "_New", NULL, N_("Create a new record"), G_CALLBACK (action_new_cb)},
-	{ "ActionCommit", GTK_STOCK_SAVE, "_Commit", NULL, N_("Commit the modifications"), G_CALLBACK (action_commit_cb)},
-	{ "ActionReset", GTK_STOCK_CLEAR, "_Clear", NULL, N_("Clear all the modifications"), G_CALLBACK (action_reset_cb)},
-	{ "ActionFirstRecord", GTK_STOCK_GOTO_FIRST, "_First record", NULL, N_("Go to first record"), G_CALLBACK (action_first_record_cb)},
-	{ "ActionLastRecord", GTK_STOCK_GOTO_LAST, "_Last record", NULL, N_("Go to last record"), G_CALLBACK (action_last_record_cb)},
-	{ "ActionPrevRecord", GTK_STOCK_GO_BACK, "_Previous record", NULL, N_("Go to previous record"), G_CALLBACK (action_prev_record_cb)},
-	{ "ActionNextRecord", GTK_STOCK_GO_FORWARD, "Ne_xt record", NULL, N_("Go to next record"), G_CALLBACK (action_next_record_cb)},
-	{ "ActionFilter", GTK_STOCK_FIND, "Filter", NULL, N_("Filter records"), G_CALLBACK (action_filter_cb)}
+	{ "ActionNew", GTK_STOCK_ADD, "_New", NULL, "Create a new data entry", G_CALLBACK (action_new_cb)},
+	{ "ActionDelete", GTK_STOCK_REMOVE, "_Delete", NULL, "Delete the selected entry", G_CALLBACK (action_delete_cb)},
+	{ "ActionUndelete", GTK_STOCK_UNDELETE, "_Undelete", NULL, "Cancels the deletion of the current entry",
+	  G_CALLBACK (action_undelete_cb)},
+	{ "ActionCommit", GTK_STOCK_SAVE, "_Commit", NULL, "Commit the latest changes", G_CALLBACK (action_commit_cb)},
+	{ "ActionReset", GTK_STOCK_REFRESH, "_Reset", NULL, "Reset the data", G_CALLBACK (action_reset_cb)},
+	{ "ActionFirstRecord", GTK_STOCK_GOTO_FIRST, "_First record", NULL, "Go to first record of records",
+	  G_CALLBACK (action_first_record_cb)},
+	{ "ActionLastRecord", GTK_STOCK_GOTO_LAST, "_Last record", NULL, "Go to last record of records",
+	  G_CALLBACK (action_last_record_cb)},
+	{ "ActionPrevRecord", GTK_STOCK_GO_BACK, "_Previous record", NULL, "Go to previous record of records",
+	  G_CALLBACK (action_prev_record_cb)},
+	{ "ActionNextRecord", GTK_STOCK_GO_FORWARD, "Ne_xt record", NULL, "Go to next record of records",
+	  G_CALLBACK (action_next_record_cb)},
+	{ "ActionFilter", GTK_STOCK_FIND, "Filter", NULL, "Filter records",
+	  G_CALLBACK (action_filter_cb)}
 };
 
 static void
@@ -224,7 +228,7 @@ form_activated_cb (GdauiRawForm *form, G_GNUC_UNUSED gpointer data)
 {
 	if (form->priv->write_mode == GDAUI_DATA_PROXY_WRITE_ON_VALUE_ACTIVATED) {
 		gint row;
-		
+
 		row = gda_data_model_iter_get_row (form->priv->iter);
 		if (row >= 0) {
 			/* write back the current row */
@@ -285,21 +289,17 @@ gdaui_raw_form_init (GdauiRawForm *wid)
 	gtk_action_group_set_translation_domain (wid->priv->actions_group, GETTEXT_PACKAGE);
 
         gtk_action_group_add_actions (wid->priv->actions_group, ui_actions, G_N_ELEMENTS (ui_actions), wid);
-        gtk_action_group_add_toggle_actions (wid->priv->actions_group, ui_actions_t, G_N_ELEMENTS (ui_actions_t), wid);
 	action = gtk_action_group_get_action (wid->priv->actions_group, "ActionNew");
 	g_signal_connect (G_OBJECT (action), "activate",
 			  G_CALLBACK (action_new_activated_cb), wid);
 
 	wid->priv->filter = NULL;
 	wid->priv->filter_window = NULL;
-
-	/* raw forms' default unknown color */
-	gdaui_basic_form_set_unknown_color ((GdauiBasicForm*) wid, -1., -1., -1., -1.);
 }
 
 /**
  * gdaui_raw_form_new:
- * @model: (allow-none): a #GdaDataModel, or %NULL
+ * @model: a #GdaDataModel, or %NULL
  *
  * Creates a new #GdauiRawForm widget to display data in @model
  *
@@ -350,8 +350,6 @@ gdaui_raw_form_dispose (GObject *object)
 							      G_CALLBACK (proxy_changed_cb), form);
 			g_signal_handlers_disconnect_by_func (G_OBJECT (form->priv->proxy),
 							      G_CALLBACK (proxy_reset_cb), form);
-			g_signal_handlers_disconnect_by_func (G_OBJECT (form->priv->proxy),
-							      G_CALLBACK (proxy_access_changed_cb), form);
 			g_object_unref (form->priv->proxy);
 			form->priv->proxy = NULL;
 		}
@@ -423,8 +421,6 @@ gdaui_raw_form_set_property (GObject *object,
 									      G_CALLBACK (proxy_changed_cb), form);
 					g_signal_handlers_disconnect_by_func (G_OBJECT (form->priv->proxy),
 									      G_CALLBACK (proxy_reset_cb), form);
-					g_signal_handlers_disconnect_by_func (G_OBJECT (form->priv->proxy),
-									      G_CALLBACK (proxy_access_changed_cb), form);
 					g_object_unref (G_OBJECT (form->priv->proxy));
 					form->priv->proxy = NULL;
 					form->priv->model = NULL;
@@ -455,14 +451,12 @@ gdaui_raw_form_set_property (GObject *object,
 							  G_CALLBACK (proxy_changed_cb), form);
 					g_signal_connect (G_OBJECT (form->priv->proxy), "reset",
 							  G_CALLBACK (proxy_reset_cb), form);
-					g_signal_connect (G_OBJECT (form->priv->proxy), "access-changed",
-							  G_CALLBACK (proxy_access_changed_cb), form);
 
 					/* we don't want chuncking */
 					g_object_set (object, "paramlist", form->priv->iter, NULL);
 					gda_data_proxy_set_sample_size (form->priv->proxy, 0);
 
-					/* handle invalid iterators' GdaHolder */
+					/* handle invalie iterators' GdaHolder */
 					GSList *list;
 					for (list = GDA_SET (form->priv->iter)->holders; list; list = list->next) {
 						GtkWidget *entry;
@@ -563,7 +557,6 @@ iter_row_changed_cb (GdaDataModelIter *iter, gint row, GdauiRawForm *form)
 							     param, !(attributes & GDA_VALUE_ATTR_NO_MODIF));
 		}
 	}
-	g_signal_emit_by_name (G_OBJECT (form), "selection-changed");
 }
 
 static void
@@ -577,20 +570,9 @@ proxy_changed_cb (G_GNUC_UNUSED GdaDataProxy *proxy, GdauiRawForm *form)
 static void
 proxy_reset_cb (GdaDataProxy *proxy, GdauiRawForm *form)
 {
-	gint row;
-	row = gda_data_model_iter_get_row (form->priv->iter);
 	g_object_ref (G_OBJECT (proxy));
 	g_object_set (G_OBJECT (form), "model", proxy, NULL);
 	g_object_unref (G_OBJECT (proxy));
-	if (row >= 0)
-		gda_data_model_iter_move_to_row (form->priv->iter, row);
-	iter_row_changed_cb (form->priv->iter, gda_data_model_iter_get_row (form->priv->iter), form);
-}
-
-static void
-proxy_access_changed_cb (G_GNUC_UNUSED GdaDataProxy *proxy, GdauiRawForm *form)
-{
-	iter_row_changed_cb (form->priv->iter, gda_data_model_iter_get_row (form->priv->iter), form);
 }
 
 static void
@@ -657,36 +639,38 @@ action_new_cb (G_GNUC_UNUSED GtkAction *action, GdauiRawForm *form)
 }
 
 static void
-action_delete_cb (GtkToggleAction *action, GdauiRawForm *form)
+action_delete_cb (G_GNUC_UNUSED GtkAction *action, GdauiRawForm *form)
 {
-	if (gtk_toggle_action_get_active (action)) {
-		gint row;
-		row = gda_data_model_iter_get_row (form->priv->iter);
-		g_return_if_fail (row >= 0);
-		gda_data_proxy_delete (form->priv->proxy, row);
-		
-		if (form->priv->write_mode >= GDAUI_DATA_PROXY_WRITE_ON_ROW_CHANGE) {
-			/* force the proxy to apply the current row deletion */
-			gint newrow;
-			
-			newrow = gda_data_model_iter_get_row (form->priv->iter);
-			if (row == newrow) {/* => row has been marked as delete but not yet really deleted */
-				GError *error = NULL;
-				if (!gda_data_proxy_apply_row_changes (form->priv->proxy, row, &error)) {
-					_gdaui_utility_display_error ((GdauiDataProxy *) form, TRUE, error);
-					if (error)
-						g_error_free (error);
-				}
+	gint row;
+
+	row = gda_data_model_iter_get_row (form->priv->iter);
+	g_return_if_fail (row >= 0);
+	gda_data_proxy_delete (form->priv->proxy, row);
+
+	if (form->priv->write_mode >= GDAUI_DATA_PROXY_WRITE_ON_ROW_CHANGE) {
+		/* force the proxy to apply the current row deletion */
+		gint newrow;
+
+		newrow = gda_data_model_iter_get_row (form->priv->iter);
+		if (row == newrow) {/* => row has been marked as delete but not yet really deleted */
+			GError *error = NULL;
+			if (!gda_data_proxy_apply_row_changes (form->priv->proxy, row, &error)) {
+				_gdaui_utility_display_error ((GdauiDataProxy *) form, TRUE, error);
+				if (error)
+					g_error_free (error);
 			}
 		}
 	}
-	else {
-		gint row;
-		
-		row = gda_data_model_iter_get_row (form->priv->iter);
-		g_return_if_fail (row >= 0);
-		gda_data_proxy_undelete (form->priv->proxy, row);
-	}
+}
+
+static void
+action_undelete_cb (G_GNUC_UNUSED GtkAction *action, GdauiRawForm *form)
+{
+	gint row;
+
+	row = gda_data_model_iter_get_row (form->priv->iter);
+	g_return_if_fail (row >= 0);
+	gda_data_proxy_undelete (form->priv->proxy, row);
 }
 
 static void
@@ -726,7 +710,7 @@ action_commit_cb (G_GNUC_UNUSED GtkAction *action, GdauiRawForm *form)
 	}
 
 	/* get to a correct selected row */
-	for (; (row >= 0) &&!gda_data_model_iter_move_to_row (form->priv->iter, row); row--);
+	for (; !gda_data_model_iter_move_to_row (form->priv->iter, row) && (row >= 0); row--);
 }
 
 static void
@@ -778,10 +762,10 @@ filter_event (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED GdkEventAny *event,
 static gboolean
 key_press_filter_event (G_GNUC_UNUSED GtkWidget *widget, GdkEventKey *event, GdauiRawForm *form)
 {
-	if (event->keyval == GDK_Escape ||
-	    event->keyval == GDK_Tab ||
-            event->keyval == GDK_KP_Tab ||
-            event->keyval == GDK_ISO_Left_Tab) {
+	if (event->keyval == GDK_KEY_Escape ||
+	    event->keyval == GDK_KEY_Tab ||
+            event->keyval == GDK_KEY_KP_Tab ||
+            event->keyval == GDK_KEY_ISO_Left_Tab) {
 		hide_filter_window (form);
 		return TRUE;
 	}
@@ -802,21 +786,16 @@ filter_position_func (GtkWidget *widget,
 	gint monitor_num;
 	GdkRectangle monitor;
 
-#if GTK_CHECK_VERSION(2,18,0)
 	window = gtk_widget_get_window (widget);
-#else
-	window = widget->window;
-#endif
-	screen = gdk_drawable_get_screen (window);
+	screen = gdk_window_get_screen (window);
 	monitor_num = gdk_screen_get_monitor_at_window (screen, window);
 	gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor);
 
 	gtk_widget_realize (search_dialog);
 
 	gdk_window_get_origin (window, &tree_x, &tree_y);
-	gdk_drawable_get_size (window,
-			       &tree_width,
-			       &tree_height);
+	tree_width = gdk_window_get_width (window);
+	tree_height = gdk_window_get_height (window);
 	gtk_widget_size_request (search_dialog, &requisition);
 
 	if (tree_x + tree_width > gdk_screen_get_width (screen))
@@ -871,15 +850,9 @@ action_filter_cb (G_GNUC_UNUSED GtkAction *action, GdauiRawForm *form)
 		gtk_widget_set_events (form->priv->filter_window,
 				       gtk_widget_get_events (form->priv->filter_window) | GDK_KEY_PRESS_MASK);
 
-#if GTK_CHECK_VERSION(2,18,0)
 		if (gtk_widget_is_toplevel (toplevel) && gtk_window_get_group ((GtkWindow*) toplevel))
 			gtk_window_group_add_window (gtk_window_get_group ((GtkWindow*) toplevel),
 						     GTK_WINDOW (form->priv->filter_window));
-#else
-		if (GTK_WIDGET_TOPLEVEL (toplevel) && GTK_WINDOW (toplevel)->group)
-			gtk_window_group_add_window (GTK_WINDOW (toplevel)->group,
-						     GTK_WINDOW (form->priv->filter_window));
-#endif
 
 		g_signal_connect (form->priv->filter_window, "delete-event",
 				  G_CALLBACK (filter_event), form);
@@ -904,7 +877,6 @@ action_filter_cb (G_GNUC_UNUSED GtkAction *action, GdauiRawForm *form)
 		}
 		gtk_container_add (GTK_CONTAINER (vbox), form->priv->filter);
 	}
-#if GTK_CHECK_VERSION(2,18,0)
 	else if (gtk_widget_is_toplevel (toplevel)) {
 		if (gtk_window_get_group ((GtkWindow*) toplevel))
 			gtk_window_group_add_window (gtk_window_get_group ((GtkWindow*) toplevel),
@@ -913,30 +885,14 @@ action_filter_cb (G_GNUC_UNUSED GtkAction *action, GdauiRawForm *form)
 			gtk_window_group_remove_window (gtk_window_get_group ((GtkWindow*) form->priv->filter_window),
 							GTK_WINDOW (form->priv->filter_window));
 	}
-#else
-	else if (GTK_WIDGET_TOPLEVEL (toplevel)) {
-		if (GTK_WINDOW (toplevel)->group)
-			gtk_window_group_add_window (GTK_WINDOW (toplevel)->group,
-						     GTK_WINDOW (form->priv->filter_window));
-		else if (GTK_WINDOW (form->priv->filter_window)->group)
-			gtk_window_group_remove_window (GTK_WINDOW (form->priv->filter_window)->group,
-							GTK_WINDOW (form->priv->filter_window));
-	}
-#endif
 
 	/* move the filter window to a correct location */
 	/* FIXME: let the user specify the position function like GtkTreeView -> search_position_func() */
-	gtk_widget_show (form->priv->filter_window);
 	gtk_grab_add (form->priv->filter_window);
 	filter_position_func (GTK_WIDGET (form), form->priv->filter_window, NULL);
 	gtk_widget_show (form->priv->filter_window);
-#if GTK_CHECK_VERSION(2,18,0)
 	popup_grab_on_window (gtk_widget_get_window (form->priv->filter_window),
 			      gtk_get_current_event_time ());
-#else
-	popup_grab_on_window (form->priv->filter_window->window,
-			      gtk_get_current_event_time ());
-#endif
 }
 
 
