@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2008 - 2009 Bas Driessen <bas.driessen@xobas.com>
- * Copyright (C) 2008 - 2009 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 Murray Cumming <murrayc@murrayc.com>
  *
  * This library is free software; you can redistribute it and/or
@@ -79,10 +79,7 @@ gda_sql_expr_free (GdaSqlExpr *expr)
 	if (!expr) return;
 
 	_gda_sql_expr_check_clean (expr);
-	if (expr->value) {
-		g_value_unset (expr->value);
-		g_free (expr->value);
-	}
+	gda_value_free (expr->value);
 	gda_sql_param_spec_free (expr->param_spec);
 	gda_sql_function_free (expr->func);
 	gda_sql_operation_free (expr->cond);
@@ -96,7 +93,7 @@ gda_sql_expr_free (GdaSqlExpr *expr)
 	}
 	gda_sql_case_free (expr->case_s);
 	g_free (expr->cast_as);
-	expr->value_is_ident = (gpointer) 0x1;
+	expr->value_is_ident = TRUE;
 	g_free (expr);
 }
 
@@ -155,10 +152,10 @@ gda_sql_expr_copy (GdaSqlExpr *expr)
  * gda_sql_expr_serialize
  * @expr: a #GdaSqlExpr structure
  *
- * Creates a new string representation of the SQL expression. You need to free the returned string
+ * Creates a new string representing a field. You need to free the returned string
  * using g_free();
  *
- * Returns: a new string with the SQL expression or "null" in case @expr is invalid.
+ * Returns: a new string with the name of the field or "null" in case @expr is invalid.
  */
 gchar *
 gda_sql_expr_serialize (GdaSqlExpr *expr)
@@ -732,11 +729,6 @@ gda_sql_operation_operator_to_string (GdaSqlOperatorType op)
 		return "NOT IN";
 	case GDA_SQL_OPERATOR_TYPE_LIKE:
 		return "LIKE";
-        /* ILIKE is a PostgreSQL extension for case-insensitive comparison.
-         * See http://developer.postgresql.org/pgdocs/postgres/functions-matching.html
-         */ 
-	case GDA_SQL_OPERATOR_TYPE_ILIKE:
-		return "ILIKE";
 	case GDA_SQL_OPERATOR_TYPE_BETWEEN:
 		return "BETWEEN";
 	case GDA_SQL_OPERATOR_TYPE_GT:
@@ -808,8 +800,6 @@ gda_sql_operation_operator_from_string (const gchar *op)
 			return GDA_SQL_OPERATOR_TYPE_IS;
 		else if (op[1] == 'N')
 			return GDA_SQL_OPERATOR_TYPE_IN;
-		else if (op[1] == 'L')
-			return GDA_SQL_OPERATOR_TYPE_ILIKE;
 		break;
 	case 'L':
 		return GDA_SQL_OPERATOR_TYPE_LIKE;
@@ -1134,15 +1124,10 @@ void
 gda_sql_select_field_take_expr (GdaSqlSelectField *field, GdaSqlExpr *expr)
 {
 	field->expr = expr;
-	g_assert (GDA_SQL_ANY_PART (expr)->type == GDA_SQL_ANY_EXPR);
 	gda_sql_any_part_set_parent (field->expr, field);
 
-	if (expr && expr->value) {
-		const gchar *dup;
-		dup = g_value_get_string (expr->value);
-		if (dup && *dup)
-			_split_identifier_string (g_strdup (dup), &(field->table_name), &(field->field_name));
-	}
+	if (expr && expr->value)
+		_split_identifier_string (g_value_dup_string (expr->value), &(field->table_name), &(field->field_name));
 }
 
 /**
