@@ -1,23 +1,22 @@
-/* 
- * Copyright (C) 2007 - 2011 The GNOME Foundation.
+/*
+ * Copyright (C) 2007 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
+ * Copyright (C) 2010 David King <davidk@openismus.com>
  *
- * AUTHORS:
- *      Vivien Malerba <malerba@gnome-db.org>
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * This Library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This Library is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #include <glib/gi18n-lib.h>
@@ -760,10 +759,8 @@ virtualRowid (sqlite3_vtab_cursor *cur, sqlite_int64 *pRowid)
 			cvalue = gda_data_model_iter_get_value_at (cursor->iter, i);
 			gvalue = gda_row_get_value (grow, i);
 			if (cvalue) {
-				if (G_VALUE_TYPE (cvalue) != GDA_TYPE_NULL) {
-					g_value_init (gvalue, G_VALUE_TYPE (cvalue));
-					g_value_copy (cvalue, gvalue);
-				}
+				gda_value_reset_with_type (gvalue, G_VALUE_TYPE (cvalue));
+				g_value_copy (cvalue, gvalue);
 			}
 			else
 				gda_row_invalidate_value (grow, gvalue);
@@ -809,6 +806,7 @@ create_value_from_sqlite3_value_notype (sqlite3_value *svalue)
 		break;
 	}
 	case SQLITE_NULL:
+		gda_value_set_null (value);
 		break;
 	case SQLITE3_TEXT:
 	default:
