@@ -812,9 +812,7 @@ gda_thread_provider_create_operation (GdaServerProvider *provider, GdaConnection
 	guint jid;
 
 	if (!cnc) {
-		g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
-			     GDA_SERVER_PROVIDER_MISUSE_ERROR,
-			     "%s", _("A connection is required"));
+		g_set_error (error, 0, 0, _("A connection is required"));
 		return NULL;
 	}
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
@@ -867,9 +865,7 @@ gda_thread_provider_render_operation (GdaServerProvider *provider, GdaConnection
 	guint jid;
 
 	if (!cnc) {
-		g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
-			     GDA_SERVER_PROVIDER_MISUSE_ERROR,
-			     "%s", _("A connection is required"));
+		g_set_error (error, 0, 0, _("A connection is required"));
 		return NULL;
 	}
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
@@ -923,16 +919,13 @@ gda_thread_provider_perform_operation (GdaServerProvider *provider, GdaConnectio
 
 	/* If asynchronous connection opening is not supported, then exit now */
 	if (async_cb) {
-		g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
-			     GDA_SERVER_PROVIDER_METHOD_NON_IMPLEMENTED_ERROR,
+		g_set_error (error, GDA_SERVER_PROVIDER_ERROR, GDA_SERVER_PROVIDER_METHOD_NON_IMPLEMENTED_ERROR,
 			     "%s", _("Provider does not support asynchronous server operation"));
                 return FALSE;
 	}
 
 	if (!cnc) {
-		g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
-			     GDA_SERVER_PROVIDER_MISUSE_ERROR,
-			     "%s", _("A connection is required"));
+		g_set_error (error, 0, 0, _("A connection is required"));
 		return FALSE;
 	}
 
@@ -987,9 +980,7 @@ gda_thread_provider_begin_transaction (GdaServerProvider *provider, GdaConnectio
 	guint jid;
 
 	if (!cnc) {
-		g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
-			     GDA_SERVER_PROVIDER_MISUSE_ERROR,
-			     "%s", _("A connection is required"));
+		g_set_error (error, 0, 0, _("A connection is required"));
 		return FALSE;
 	}
 
@@ -1044,9 +1035,7 @@ gda_thread_provider_commit_transaction (GdaServerProvider *provider, GdaConnecti
 	guint jid;
 
 	if (!cnc) {
-		g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
-			     GDA_SERVER_PROVIDER_MISUSE_ERROR,
-			     "%s", _("A connection is required"));
+		g_set_error (error, 0, 0, _("A connection is required"));
 		return FALSE;
 	}
 
@@ -1093,9 +1082,7 @@ gda_thread_provider_rollback_transaction (GdaServerProvider *provider, GdaConnec
 	guint jid;
 
 	if (!cnc) {
-		g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
-			     GDA_SERVER_PROVIDER_MISUSE_ERROR,
-			     "%s", _("A connection is required"));
+		g_set_error (error, 0, 0, _("A connection is required"));
 		return FALSE;
 	}
 
@@ -1142,9 +1129,7 @@ gda_thread_provider_add_savepoint (GdaServerProvider *provider, GdaConnection *c
 	guint jid;
 
 	if (!cnc) {
-		g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
-			     GDA_SERVER_PROVIDER_MISUSE_ERROR,
-			     "%s", _("A connection is required"));
+		g_set_error (error, 0, 0, _("A connection is required"));
 		return FALSE;
 	}
 
@@ -1191,9 +1176,7 @@ gda_thread_provider_rollback_savepoint (GdaServerProvider *provider, GdaConnecti
 	guint jid;
 
 	if (!cnc) {
-		g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
-			     GDA_SERVER_PROVIDER_MISUSE_ERROR,
-			     "%s", _("A connection is required"));
+		g_set_error (error, 0, 0, _("A connection is required"));
 		return FALSE;
 	}
 
@@ -1240,9 +1223,7 @@ gda_thread_provider_delete_savepoint (GdaServerProvider *provider, GdaConnection
 	guint jid;
 
 	if (!cnc) {
-		g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
-			     GDA_SERVER_PROVIDER_MISUSE_ERROR,
-			     "%s", _("A connection is required"));
+		g_set_error (error, 0, 0, _("A connection is required"));
 		return FALSE;
 	}
 
@@ -1379,7 +1360,7 @@ gda_thread_provider_get_default_dbms_type (GdaServerProvider *provider, GdaConne
 
 	cdata = (ThreadConnectionData*) gda_connection_internal_get_provider_data (cnc);
 	if (!cdata) 
-		return NULL;
+		return FALSE;
 	
 	wdata.prov = cdata->cnc_provider;
 	wdata.cnc = cdata->sub_connection;
@@ -1641,7 +1622,7 @@ gda_thread_provider_statement_execute (GdaServerProvider *provider, GdaConnectio
 
 	if (check_cnc_closed (cnc, cdata)) {
 		g_set_error (error, GDA_CONNECTION_ERROR, GDA_CONNECTION_CLOSED_ERROR,
-			     "%s", _("Connection is closed"));
+			     _("Connection is closed"));
 		return NULL;
 	}
 	
@@ -1772,9 +1753,7 @@ gda_thread_provider_xa_start (GdaServerProvider *provider, GdaConnection *cnc,
 	guint jid;
 
 	if (!cnc) {
-		g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
-			     GDA_SERVER_PROVIDER_MISUSE_ERROR,
-			     "%s", _("A connection is required"));
+		g_set_error (error, 0, 0, _("A connection is required"));
 		return FALSE;
 	}
 
@@ -1823,9 +1802,7 @@ gda_thread_provider_xa_end (GdaServerProvider *provider, GdaConnection *cnc,
 	guint jid;
 
 	if (!cnc) {
-		g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
-			     GDA_SERVER_PROVIDER_MISUSE_ERROR,
-			     "%s", _("A connection is required"));
+		g_set_error (error, 0, 0, _("A connection is required"));
 		return FALSE;
 	}
 
@@ -1873,9 +1850,7 @@ gda_thread_provider_xa_prepare (GdaServerProvider *provider, GdaConnection *cnc,
 	guint jid;
 
 	if (!cnc) {
-		g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
-			     GDA_SERVER_PROVIDER_MISUSE_ERROR,
-			     "%s", _("A connection is required"));
+		g_set_error (error, 0, 0, _("A connection is required"));
 		return FALSE;
 	}
 
@@ -1924,9 +1899,7 @@ gda_thread_provider_xa_commit (GdaServerProvider *provider, GdaConnection *cnc,
 	guint jid;
 
 	if (!cnc) {
-		g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
-			     GDA_SERVER_PROVIDER_MISUSE_ERROR,
-			     "%s", _("A connection is required"));
+		g_set_error (error, 0, 0, _("A connection is required"));
 		return FALSE;
 	}
 
@@ -1974,9 +1947,7 @@ gda_thread_provider_xa_rollback (GdaServerProvider *provider, GdaConnection *cnc
 	guint jid;
 
 	if (!cnc) {
-		g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
-			     GDA_SERVER_PROVIDER_MISUSE_ERROR,
-			     "%s", _("A connection is required"));
+		g_set_error (error, 0, 0, _("A connection is required"));
 		return FALSE;
 	}
 
@@ -2025,9 +1996,7 @@ gda_thread_provider_xa_recover (GdaServerProvider *provider, GdaConnection *cnc,
 	guint jid;
 
 	if (!cnc) {
-		g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
-			     GDA_SERVER_PROVIDER_MISUSE_ERROR,
-			     "%s", _("A connection is required"));
+		g_set_error (error, 0, 0, _("A connection is required"));
 		return FALSE;
 	}
 
