@@ -267,8 +267,11 @@ gda_jdbc_recordset_new (GdaConnection *cnc, GdaJdbcPStmt *ps, GdaSet *exec_param
 									 gda_column_new ());
 		_GDA_PSTMT (ps)->tmpl_columns = g_slist_reverse (_GDA_PSTMT (ps)->tmpl_columns);
 
-		/* create prepared statement's types */
-		_GDA_PSTMT (ps)->types = g_new0 (GType, _GDA_PSTMT (ps)->ncols); /* all types are initialized to GDA_TYPE_NULL */
+		/* create prepared statement's types, all types are initialized to GDA_TYPE_NULL */
+		_GDA_PSTMT (ps)->types = g_new (GType, _GDA_PSTMT (ps)->ncols);
+		for (i = 0; i < _GDA_PSTMT (ps)->ncols; i++)
+			_GDA_PSTMT (ps)->types [i] = GDA_TYPE_NULL;
+
 		if (col_types) {
 			for (i = 0; ; i++) {
 				if (col_types [i] > 0) {
@@ -366,7 +369,7 @@ gda_jdbc_recordset_new (GdaConnection *cnc, GdaJdbcPStmt *ps, GdaSet *exec_param
 	}
 	
 	jexec_res = jni_wrapper_method_call (jenv, GdaJResultSet__declareColumnTypes,
-					     rs_value, &error_code, &sql_state, &error, (jlong)GPOINTER_TO_INT(cnc), jtypes);
+					     rs_value, &error_code, &sql_state, &error, (jlong) cnc, jtypes);
 	(*jenv)->DeleteLocalRef (jenv, jtypes);
 	g_free (ctypes);
 	
@@ -410,13 +413,11 @@ fetch_next_jdbc_row (GdaJdbcRecordset *model, JNIEnv *jenv, gboolean do_store, G
 	prow = gda_row_new (_GDA_PSTMT (ps)->ncols);
 
 	jexec_res = jni_wrapper_method_call (jenv, GdaJResultSet__fillNextRow,
-					     model->priv->rs_value, &error_code, &sql_state, &lerror,
-					     (jlong)GPOINTER_TO_INT(prow));
+					     model->priv->rs_value, &error_code, &sql_state, &lerror, (jlong) prow);
 	if (!jexec_res) {
 		if (error && lerror)
 			*error = g_error_copy (lerror);
 		_gda_jdbc_make_error (model->priv->cnc, error_code, sql_state, lerror);
-		g_object_unref ((GObject*) prow);
 		return NULL;
 	}
 
@@ -424,7 +425,6 @@ fetch_next_jdbc_row (GdaJdbcRecordset *model, JNIEnv *jenv, gboolean do_store, G
 	gda_value_free (jexec_res);
 	if (! row_found) {
 		GDA_DATA_SELECT (model)->advertized_nrows = model->priv->next_row_num;
-		g_object_unref ((GObject*) prow);
 		return NULL;
 	}
 
@@ -468,8 +468,7 @@ gda_jdbc_recordset_fetch_nb_rows (GdaDataSelect *model)
 /*
  * Create a new filled #GdaRow object for the row at position @rownum.
  *
- * Each new #GdaRow created is "given" to the #GdaDataSelect implementation
- * using gda_data_select_take_row ().
+ * Each new #GdaRow created is "given" to the #GdaDataSelect implementation using gda_data_select_take_row ().
  */
 static gboolean 
 gda_jdbc_recordset_fetch_random (GdaDataSelect *model, GdaRow **prow, gint rownum, GError **error)
@@ -480,18 +479,23 @@ gda_jdbc_recordset_fetch_random (GdaDataSelect *model, GdaRow **prow, gint rownu
 
 	jenv = _gda_jdbc_get_jenv (&jni_detach, NULL);
 	if (!jenv)
-		return TRUE;
+		return FALSE;
 
 	imodel = GDA_JDBC_RECORDSET (model);
-	if (imodel->priv->next_row_num >= rownum) {
-		g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
-			     GDA_SERVER_PROVIDER_INTERNAL_ERROR, 
-			     "%s", _("Requested row could not be found"));
-		return TRUE;
-	}
-	for (*prow = fetch_next_jdbc_row (imodel, jenv, TRUE, error);
-	     *prow && (imodel->priv->next_row_num < rownum);
-	     *prow = fetch_next_jdbc_row (imodel, jenv, TRUE, error));
+        for (; imodel->priv->next_row_num <= rownum; ) {
+                *prow = fetch_next_jdbc_row (imodel, jenv, TRUE, error);
+                if (!*prow) {
+                        /*if (GDA_DATA_SELECT (model)->advertized_nrows >= 0), it's not an error */
+                        if ((GDA_DATA_SELECT (model)->advertized_nrows >= 0) &&
+                            (imodel->priv->next_row_num < rownum)) {
+                                g_set_error (error, 0,
+                                             GDA_DATA_MODEL_ROW_OUT_OF_RANGE_ERROR,
+                                             _("Row %d not found"), rownum);
+                        }
+			_gda_jdbc_release_jenv (jni_detach);
+                        return FALSE;
+                }
+        }
 
 	_gda_jdbc_release_jenv (jni_detach);
         return TRUE;
@@ -501,11 +505,10 @@ gda_jdbc_recordset_fetch_random (GdaDataSelect *model, GdaRow **prow, gint rownu
  * Create a new filled #GdaRow object for the next cursor row, and put it into *prow.
  *
  * Each new #GdaRow created is referenced only by imodel->priv->tmp_row (the #GdaDataSelect implementation
- * never keeps a reference to it). Before a new #GdaRow gets created, the previous one,
- * if set, is discarded.
+ * never keeps a reference to it). Before a new #GdaRow gets created, the previous one, if set, is discarded.
  */
 static gboolean 
-gda_jdbc_recordset_fetch_next (GdaDataSelect *model, GdaRow **prow, gint rownum, GError **error)
+gda_jdbc_recordset_fetch_next (GdaDataSelect *model, GdaRow **prow, G_GNUC_UNUSED gint rownum, GError **error)
 {
 	GdaJdbcRecordset *imodel = (GdaJdbcRecordset*) model;
 	JNIEnv *jenv = NULL;
@@ -515,23 +518,12 @@ gda_jdbc_recordset_fetch_next (GdaDataSelect *model, GdaRow **prow, gint rownum,
 	if (!jenv)
 		return FALSE;
 
-	if (imodel->priv->tmp_row) {
+	if (*prow)
+                return TRUE;
+
+	if (imodel->priv->tmp_row)
                 g_object_unref (imodel->priv->tmp_row);
-		imodel->priv->tmp_row = NULL;
-	}
-	if (imodel->priv->next_row_num != rownum) {
-		GError *lerror = NULL;
-		*prow = NULL;
-		g_set_error (&lerror, GDA_DATA_MODEL_ERROR,
-			     GDA_DATA_MODEL_ROW_NOT_FOUND_ERROR,
-			     "%s", _("Can't set iterator on requested row"));
-		gda_data_select_add_exception (GDA_DATA_SELECT (model), lerror);
-		if (error)
-			g_propagate_error (error, g_error_copy (lerror));
-		_gda_jdbc_release_jenv (jni_detach);
 
-		return TRUE;
-	}
         *prow = fetch_next_jdbc_row (imodel, jenv, FALSE, error);
         imodel->priv->tmp_row = *prow;
 
