@@ -798,7 +798,8 @@ gdaprov_ldap_get_top_classes (GdaLdapConnection *cnc)
 		return NULL;
 	if (! cdata->classes_hash) {
 		/* force classes init */
-		gdaprov_ldap_get_class_info (cnc, "top");
+		GdaLdapClass *lcl;
+		lcl = gdaprov_ldap_get_class_info (cnc, "top");
 	}
 	return cdata->top_classes;
 }
@@ -1065,9 +1066,6 @@ gda_ldap_parse_dn (const char *attr, gchar **out_userdn)
 	if (out_userdn)
 		*out_userdn = NULL;
 
-	if (!attr)
-		return FALSE;
-
 	/* decoding */
 	if (ldap_str2dn (attr, &tmpDN, LDAP_DN_FORMAT_LDAPV3) != LDAP_SUCCESS) {
 		if (ldap_str2dn (attr, &tmpDN, LDAP_DN_FORMAT_LDAPV2) != LDAP_SUCCESS) {
@@ -1140,10 +1138,8 @@ gdaprov_ldap_describe_entry (GdaLdapConnection *cnc, const gchar *dn, GError **e
 			return NULL;
 		}
 		else if (nb_entries > 1) {
-			g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
-				     GDA_SERVER_PROVIDER_INTERNAL_ERROR,
-				     _("LDAP server returned more than one entry with DN '%s'"),
-				     real_dn);
+			g_set_error (error, 0, 0,
+				     _("LDAP server returned more than one entry with DN '%s'"), real_dn);
 			return NULL;
 		}
 
@@ -1274,9 +1270,7 @@ gdaprov_ldap_get_entry_children (GdaLdapConnection *cnc, const gchar *dn, gchar
 				}
 				g_array_free (children, TRUE);
 				children = NULL;
-				g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
-					     GDA_SERVER_PROVIDER_INTERNAL_ERROR,
-					     "%s",
+				g_set_error (error, 0, 0,
 					     _("Could not parse distinguished name returned by LDAP server"));
 				break;
 			}
