@@ -105,7 +105,7 @@ static GObjectClass *parent_class = NULL;
  */
 static void
 gda_mysql_recordset_init (GdaMysqlRecordset       *recset,
-			  G_GNUC_UNUSED GdaMysqlRecordsetClass  *klass)
+			  GdaMysqlRecordsetClass  *klass)
 {
 	g_return_if_fail (GDA_IS_MYSQL_RECORDSET (recset));
 	recset->priv = g_new0 (GdaMysqlRecordsetPrivate, 1);
@@ -298,8 +298,7 @@ gda_mysql_recordset_get_type (void)
 			NULL,
 			sizeof (GdaMysqlRecordset),
 			0,
-			(GInstanceInitFunc) gda_mysql_recordset_init,
-			NULL
+			(GInstanceInitFunc) gda_mysql_recordset_init
 		};
 		g_static_mutex_lock (&registering);
 		if (type == 0)
@@ -311,10 +310,10 @@ gda_mysql_recordset_get_type (void)
 }
 
 static GType
-_gda_mysql_type_to_gda (G_GNUC_UNUSED MysqlConnectionData *cdata,
+_gda_mysql_type_to_gda (MysqlConnectionData *cdata,
 			enum enum_field_types  mysql_type, unsigned int charsetnr)
 {
-	GType gtype = 0;
+	GType gtype;
 	switch (mysql_type) {
 	case MYSQL_TYPE_TINY:
 	case MYSQL_TYPE_SHORT:
@@ -331,8 +330,6 @@ _gda_mysql_type_to_gda (G_GNUC_UNUSED MysqlConnectionData *cdata,
 		break;
 	case MYSQL_TYPE_DECIMAL:
 	case MYSQL_TYPE_NEWDECIMAL:
-		gtype = GDA_TYPE_NUMERIC;
-		break;
 	case MYSQL_TYPE_DOUBLE:
 		gtype = G_TYPE_DOUBLE;
 		break;
@@ -465,7 +462,7 @@ gda_mysql_recordset_new_direct (GdaConnection *cnc, GdaDataModelAccessFlags flag
 		MYSQL_FIELD *field = &mysql_fields[i];
 		
 		GType gtype = model->priv->types [i];
-		if (gtype == 0) {
+		if (gtype == GDA_TYPE_NULL) {
 			gtype = _gda_mysql_type_to_gda (cdata, field->type, field->charsetnr);
 			model->priv->types [i] = gtype;
 		}
@@ -562,8 +559,11 @@ gda_mysql_recordset_new (GdaConnection            *cnc,
 									 gda_column_new ());
 		_GDA_PSTMT (ps)->tmpl_columns = g_slist_reverse (_GDA_PSTMT (ps)->tmpl_columns);
 
-		/* create prepared statement's types */
-		_GDA_PSTMT (ps)->types = g_new0 (GType, _GDA_PSTMT (ps)->ncols); /* all types are initialized to GDA_TYPE_NULL */
+		/* create prepared statement's types, all types are initialized to GDA_TYPE_NULL */
+		_GDA_PSTMT (ps)->types = g_new (GType, _GDA_PSTMT (ps)->ncols);
+		for (i = 0; i < _GDA_PSTMT (ps)->ncols; i++)
+			_GDA_PSTMT (ps)->types [i] = GDA_TYPE_NULL;
+
 		if (col_types) {
 			for (i = 0; ; i++) {
 				if (col_types [i] > 0) {
@@ -609,7 +609,7 @@ gda_mysql_recordset_new (GdaConnection            *cnc,
 		MYSQL_FIELD *field = &mysql_fields[i];
 		
 		GType gtype = _GDA_PSTMT(ps)->types[i];
-		if (gtype == 0) {
+		if (gtype == GDA_TYPE_NULL) {
 			gtype = _gda_mysql_type_to_gda (cdata, field->type, field->charsetnr);
 			_GDA_PSTMT(ps)->types[i] = gtype;
 		}
@@ -651,7 +651,6 @@ gda_mysql_recordset_new (GdaConnection            *cnc,
 		case MYSQL_TYPE_TINY_BLOB:
 		case MYSQL_TYPE_MEDIUM_BLOB:
 		case MYSQL_TYPE_LONG_BLOB:
-		case MYSQL_TYPE_DECIMAL:
 		case MYSQL_TYPE_NEWDECIMAL:
 		case MYSQL_TYPE_BIT:
 			mysql_bind_result[i].buffer = g_malloc0 (field->max_length + 1);
@@ -716,7 +715,7 @@ gda_mysql_recordset_fetch_nb_rows (GdaDataSelect *model)
 }
 
 static GdaRow *
-new_row_from_mysql_stmt (GdaMysqlRecordset *imodel, G_GNUC_UNUSED gint rownum, GError **error)
+new_row_from_mysql_stmt (GdaMysqlRecordset *imodel, gint rownum, GError **error)
 {
 	//g_print ("%s(): NCOLS=%d  ROWNUM=%d\n", __func__, ((GdaDataSelect *) imodel)->prep_stmt->ncols, rownum);
 	int res;
@@ -777,7 +776,7 @@ new_row_from_mysql_stmt (GdaMysqlRecordset *imodel, G_GNUC_UNUSED gint rownum, G
 		long long longlongvalue = 0;
 		double doublevalue = 0.0;
 		float floatvalue = 0.;
-		MYSQL_TIME timevalue = { 0, 0, 0, 0, 0, 0, 0, 0, 0 };
+		MYSQL_TIME timevalue = { 0 };
 		my_bool is_null = FALSE;
 		unsigned long length;
 		
@@ -829,8 +828,7 @@ new_row_from_mysql_stmt (GdaMysqlRecordset *imodel, G_GNUC_UNUSED gint rownum, G
 			}
 			break;
 		case MYSQL_TYPE_NULL:
-			if (G_IS_VALUE(value))
-				g_value_unset (value);
+			gda_value_set_null (value);
 			break;
 		case MYSQL_TYPE_TIME:
 		case MYSQL_TYPE_DATE:
@@ -912,7 +910,6 @@ new_row_from_mysql_stmt (GdaMysqlRecordset *imodel, G_GNUC_UNUSED gint rownum, G
 		case MYSQL_TYPE_MEDIUM_BLOB:
 		case MYSQL_TYPE_LONG_BLOB:
 		case MYSQL_TYPE_NEWDECIMAL:
-		case MYSQL_TYPE_DECIMAL:
 		case MYSQL_TYPE_BIT: {
 			char *strvalue = NULL;
 			g_memmove (&length, mysql_bind_result[i].length, sizeof(unsigned long));
@@ -932,24 +929,16 @@ new_row_from_mysql_stmt (GdaMysqlRecordset *imodel, G_GNUC_UNUSED gint rownum, G
 				gda_value_set_binary (value, &binary);
 			}
 			else if (type == GDA_TYPE_BLOB) {
-				/* we don't use GdaMysqlBlobOp because it looks like the MySQL
+				/* web don't use GdaMysqlBlobOp because it looks like the MySQL
 				 * API does not support BLOBs accessed in a random way,
 				 * so we return the whole BLOB at once */
-				GdaBlob blob = { {(guchar*) strvalue, length}, NULL };
+				GdaBlob blob = {
+					.data.data = (guchar*) strvalue,
+					.data.binary_length = length,
+					.op = NULL
+				};
 				gda_value_set_blob (value, &blob);
 			}
-			else if (type == GDA_TYPE_NUMERIC) {
-				setlocale (LC_NUMERIC, "C");
-				if (length > 0) {
-					GdaNumeric *numeric;
-					numeric = g_new0 (GdaNumeric, 1);
-					numeric->number = g_strdup (strvalue);
-					numeric->width = length;
-					gda_value_set_numeric (value, numeric);
-					gda_numeric_free (numeric);
-				}
-				setlocale (LC_NUMERIC, gda_numeric_locale);
-			}
 			else if (type == G_TYPE_DOUBLE) {
 				if (length > 0) {
 					setlocale (LC_NUMERIC, "C");
@@ -1018,7 +1007,17 @@ new_row_from_mysql_stmt (GdaMysqlRecordset *imodel, G_GNUC_UNUSED gint rownum, G
 /*
  * Create a new filled #GdaRow object for the row at position @rownum, and put it into *row.
  *
- * Each new GdaRow is given to @model using gda_data_select_take_row().
+ * WARNING: @row will NOT be NULL, but *row may or may not be NULL:
+ *  -  If *row is NULL then a new #GdaRow object has to be created, 
+ *  -  and otherwise *row contains a #GdaRow object which has already been created 
+ *     (through a call to this very function), and in this case it should not be modified
+ *     but the function may return FALSE if an error occurred.
+ *
+ * Memory management for that new GdaRow object is left to the implementation, which
+ * can use gda_data_select_take_row(). If new row objects are "given" to the GdaDataSelect implemantation
+ * using that method, then this method should detect when all the data model rows have been analyzed
+ * (when model->nb_stored_rows == model->advertized_nrows) and then possibly discard the API handle
+ * as it won't be used anymore to fetch rows.
  */
 static gboolean 
 gda_mysql_recordset_fetch_random (GdaDataSelect  *model,
@@ -1030,9 +1029,12 @@ gda_mysql_recordset_fetch_random (GdaDataSelect  *model,
 
 	imodel = GDA_MYSQL_RECORDSET (model);
 
+	if (*row)
+		return TRUE;
+	
 	*row = new_row_from_mysql_stmt (imodel, rownum, error);
 	if (!*row)
-		return TRUE;
+		return FALSE;
 
 	gda_data_select_take_row (model, *row, rownum);
 	
@@ -1048,9 +1050,14 @@ gda_mysql_recordset_fetch_random (GdaDataSelect  *model,
 /*
  * Create a new filled #GdaRow object for the next cursor row, and put it into *row.
  *
- * Each new #GdaRow created is referenced only by imodel->priv->tmp_row (the #GdaDataSelect implementation
- * never keeps a reference to it).
- * Before a new #GdaRow gets created, the previous one, if set, is discarded.
+ * WARNING: @row will NOT be NULL, but *row may or may not be NULL:
+ *  -  If *row is NULL then a new #GdaRow object has to be created, 
+ *  -  and otherwise *row contains a #GdaRow object which has already been created 
+ *     (through a call to this very function), and in this case it should not be modified
+ *     but the function may return FALSE if an error occurred.
+ *
+ * Memory management for that new GdaRow object is left to the implementation, which
+ * can use gda_data_select_take_row().
  */
 static gboolean 
 gda_mysql_recordset_fetch_next (GdaDataSelect  *model,
@@ -1060,20 +1067,33 @@ gda_mysql_recordset_fetch_next (GdaDataSelect  *model,
 {
 	GdaMysqlRecordset *imodel = (GdaMysqlRecordset*) model;
 
-	if (imodel->priv->tmp_row)
+	// TO_IMPLEMENT;
+
+	// gda_data_select_iter_next () increments rownum
+
+	if (imodel->priv->tmp_row != NULL) {
 		g_object_unref (G_OBJECT(imodel->priv->tmp_row));
+		imodel->priv->tmp_row = NULL;
+	}
+	
 	*row = new_row_from_mysql_stmt (imodel, rownum, error);
+
 	imodel->priv->tmp_row = *row;
 
-	return TRUE;
+	return *row ? TRUE : FALSE;
 }
 
 /*
- * Create a new filled #GdaRow object for the previous cursor row, and put it into *prow.
+ * Create a new filled #GdaRow object for the previous cursor row, and put it into *row.
  *
- * Each new #GdaRow created is referenced only by imodel->priv->tmp_row (the #GdaDataSelect implementation
- * never keeps a reference to it).
- * Before a new #GdaRow gets created, the previous one, if set, is discarded.
+ * WARNING: @row will NOT be NULL, but *row may or may not be NULL:
+ *  -  If *row is NULL then a new #GdaRow object has to be created, 
+ *  -  and otherwise *row contains a #GdaRow object which has already been created 
+ *     (through a call to this very function), and in this case it should not be modified
+ *     but the function may return FALSE if an error occurred.
+ *
+ * Memory management for that new GdaRow object is left to the implementation, which
+ * can use gda_data_select_take_row().
  */
 static gboolean 
 gda_mysql_recordset_fetch_prev (GdaDataSelect  *model,
@@ -1081,12 +1101,9 @@ gda_mysql_recordset_fetch_prev (GdaDataSelect  *model,
 				gint            rownum,
 				GError        **error)
 {
-	GdaMysqlRecordset *imodel = (GdaMysqlRecordset*) model;
+	/*GdaMysqlRecordset *imodel = (GdaMysqlRecordset*) model;*/
 
-	if (imodel->priv->tmp_row)
-		g_object_unref (G_OBJECT(imodel->priv->tmp_row));
-	*row = new_row_from_mysql_stmt (imodel, rownum, error);
-	imodel->priv->tmp_row = *row;
+	TO_IMPLEMENT;
 
 	return TRUE;
 }
@@ -1094,9 +1111,14 @@ gda_mysql_recordset_fetch_prev (GdaDataSelect  *model,
 /*
  * Create a new filled #GdaRow object for the cursor row at position @rownum, and put it into *row.
  *
- * Each new #GdaRow created is referenced only by imodel->priv->tmp_row (the #GdaDataSelect implementation
- * never keeps a reference to it).
- * Before a new #GdaRow gets created, the previous one, if set, is discarded.
+ * WARNING: @row will NOT be NULL, but *row may or may not be NULL:
+ *  -  If *row is NULL then a new #GdaRow object has to be created, 
+ *  -  and otherwise *row contains a #GdaRow object which has already been created 
+ *     (through a call to this very function), and in this case it should not be modified
+ *     but the function may return FALSE if an error occurred.
+ *
+ * Memory management for that new GdaRow object is left to the implementation, which
+ * can use gda_data_select_take_row().
  */
 static gboolean 
 gda_mysql_recordset_fetch_at (GdaDataSelect  *model,
@@ -1104,12 +1126,9 @@ gda_mysql_recordset_fetch_at (GdaDataSelect  *model,
 			      gint            rownum,
 			      GError        **error)
 {
-	GdaMysqlRecordset *imodel = (GdaMysqlRecordset*) model;
-
-	if (imodel->priv->tmp_row)
-		g_object_unref (G_OBJECT(imodel->priv->tmp_row));
-	*row = new_row_from_mysql_stmt (imodel, rownum, error);
-	imodel->priv->tmp_row = *row;
+	/*GdaMysqlRecordset *imodel = (GdaMysqlRecordset*) model;*/
+	
+	TO_IMPLEMENT;
 
 	return TRUE;
 }
