@@ -149,33 +149,10 @@ prov_test_check_types_schema (GdaConnection *cnc)
 		return FALSE;
 	}
 
-	GdaServerProvider *prov;
 	GdaDataModel *schema_m;
 	GError *error = NULL;
 	gchar *str;
-	GdaMetaContext mcontext = {"_builtin_data_types", 0, NULL, NULL};
-	g_print ("updating [%s]\n", mcontext.table_name);
-	if (! gda_connection_update_meta_store (cnc, &mcontext, &error)) {
-		g_warning ("Can't update meta store: %s\n",
-			   error && error->message ? error->message : "???");
-		return FALSE;
-	}
-	mcontext.table_name="_udt";
-	g_print ("updating [%s]\n", mcontext.table_name);
-	if (! gda_connection_update_meta_store (cnc, &mcontext, &error)) {
-		g_warning ("Can't update meta store: %s\n",
-			   error && error->message ? error->message : "???");
-		return FALSE;
-	}
-	mcontext.table_name="_domains";
-	g_print ("updating [%s]\n", mcontext.table_name);
-	if (! gda_connection_update_meta_store (cnc, &mcontext, &error)) {
-		g_warning ("Can't update meta store: %s\n",
-			   error && error->message ? error->message : "???");
-		return FALSE;
-	}
 	
-	prov = gda_connection_get_provider (cnc);
 	schema_m = gda_connection_get_meta_store_data (cnc, GDA_CONNECTION_META_TYPES, &error, 0);
 	if (!schema_m) {
 #ifdef CHECK_EXTRA_INFO
@@ -309,7 +286,7 @@ iter_is_correct (GdaDataModelIter *iter, GdaDataModel *ref_model)
         g_object_get (G_OBJECT (iter), "current-row", &rownum, NULL);
 
         cols = gda_data_model_get_n_columns (ref_model);
-        if (cols != (gint)g_slist_length (GDA_SET (iter)->holders)) {
+        if (cols != g_slist_length (GDA_SET (iter)->holders)) {
 #ifdef CHECK_EXTRA_INFO
                 g_warning ("Number of columns in iter is not the same as for the referenced data model\n");
 #endif
