@@ -103,10 +103,8 @@ struct _BrowserWindowPrivate {
 	gulong             cnc_added_sigid;
 	gulong             cnc_removed_sigid;
 
-#if GTK_CHECK_VERSION (2,18,0)
 	GtkWidget         *notif_box;
 	GSList            *notif_widgets;
-#endif
 
 	GtkWidget         *statusbar;
 	guint              cnc_statusbar_context;
@@ -234,10 +232,8 @@ browser_window_dispose (GObject *object)
 		if (bwin->priv->perspectives_nb)
 			g_object_unref (bwin->priv->perspectives_nb);
 
-#if GTK_CHECK_VERSION (2,18,0)
 		if (bwin->priv->notif_widgets)
 			g_slist_free (bwin->priv->notif_widgets);
-#endif
 		g_free (bwin->priv);
 		bwin->priv = NULL;
 	}
@@ -383,6 +379,9 @@ BrowserWindow*
 browser_window_new (BrowserConnection *bcnc, BrowserPerspectiveFactory *factory)
 {
 	BrowserWindow *bwin;
+	const gchar *cncname;
+	const GdaDsnInfo *dsn;
+	GString *title;
 
 	g_return_val_if_fail (BROWSER_IS_CONNECTION (bcnc), NULL);
 
@@ -391,11 +390,19 @@ browser_window_new (BrowserConnection *bcnc, BrowserPerspectiveFactory *factory)
 	g_signal_connect (bcnc, "transaction-status-changed",
 			  G_CALLBACK (transaction_status_changed_cb), bwin);
 
-	gchar *tmp;
-	tmp = browser_connection_get_long_name (bcnc);
-	gtk_window_set_title (GTK_WINDOW (bwin), tmp);
-	g_free (tmp);
-
+	dsn = browser_connection_get_information (bcnc);
+	cncname = browser_connection_get_name (bcnc);
+	title = g_string_new (_("Connection"));
+	g_string_append (title, " ");
+	g_string_append_printf (title, "'%s'", cncname ? cncname : _("unnamed"));
+	if (dsn) {
+		if (dsn->name)
+			g_string_append_printf (title, ", %s '%s'", _("data source"), dsn->name);
+		if (dsn->provider)
+			g_string_append_printf (title, " (%s)", dsn->provider);
+	}
+	gtk_window_set_title (GTK_WINDOW (bwin), title->str);
+	g_string_free (title, TRUE);
 	gtk_window_set_default_size ((GtkWindow*) bwin, 900, 650);
 	g_signal_connect (G_OBJECT (bwin), "delete-event",
                           G_CALLBACK (delete_event), bwin);
@@ -465,12 +472,10 @@ browser_window_new (BrowserConnection *bcnc, BrowserPerspectiveFactory *factory)
         gtk_widget_show (toolbar);
 	bwin->priv->toolbar_style = gtk_toolbar_get_style (GTK_TOOLBAR (toolbar));
 
-#if GTK_CHECK_VERSION (2,18,0)
 	bwin->priv->notif_box = gtk_vbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), bwin->priv->notif_box, FALSE, FALSE, 0);
         gtk_widget_show (bwin->priv->notif_box);
 	bwin->priv->notif_widgets = NULL;
-#endif
 
 	GtkToolItem *ti;
 	GtkWidget *spinner, *svbox, *align;
@@ -493,7 +498,6 @@ browser_window_new (BrowserConnection *bcnc, BrowserPerspectiveFactory *factory)
 	gtk_container_add (GTK_CONTAINER (ti), svbox);
 	gtk_toolbar_insert (GTK_TOOLBAR (toolbar), ti, -1);
         gtk_widget_show_all (GTK_WIDGET (ti));
-	gtk_widget_hide (GTK_WIDGET (spinner));
 	bwin->priv->spinner = spinner;
 
 	/* statusbar */
@@ -517,8 +521,6 @@ browser_window_new (BrowserConnection *bcnc, BrowserPerspectiveFactory *factory)
 
 	/* create a PerspectiveData */
 	PerspectiveData *pers;
-	if (! factory && browser_connection_is_ldap (bcnc))
-		factory = browser_core_get_factory (_("LDAP browser"));
 	pers = perspective_data_new (bwin, factory);
 	bwin->priv->perspectives = g_slist_prepend (bwin->priv->perspectives, pers);
 	GtkActionGroup *actions;
@@ -545,8 +547,7 @@ browser_window_new (BrowserConnection *bcnc, BrowserPerspectiveFactory *factory)
         bwin->priv->perspectives_nb = (GtkNotebook*) gtk_notebook_new ();
         g_object_ref (bwin->priv->perspectives_nb);
         gtk_notebook_set_show_tabs (bwin->priv->perspectives_nb, FALSE);
-	gtk_box_pack_start (GTK_BOX (vbox), (GtkWidget*) bwin->priv->perspectives_nb,
-			    TRUE, TRUE, 0);
+	gtk_container_add (GTK_CONTAINER (vbox), (GtkWidget*) bwin->priv->perspectives_nb);
 
 	pers->page_number = gtk_notebook_append_page (bwin->priv->perspectives_nb,
 						      GTK_WIDGET (pers->perspective_widget), NULL);
@@ -611,16 +612,7 @@ browser_window_new (BrowserConnection *bcnc, BrowserPerspectiveFactory *factory)
 
         gtk_widget_show (GTK_WIDGET (bwin));
 
-#if GTK_CHECK_VERSION(2,18,0)
 	gtk_widget_set_can_focus ((GtkWidget* )pers->perspective_widget, TRUE);
-#else
-	GtkWidget *fwid = (GtkWidget* )pers->perspective_widget;
-	if (! GTK_WIDGET_CAN_FOCUS (fwid)) {
-		GTK_WIDGET_SET_FLAGS (fwid, GTK_CAN_FOCUS);
-		gtk_widget_queue_resize (fwid);
-		g_object_notify (G_OBJECT (fwid), "can-focus");
-	}
-#endif
 	gtk_widget_grab_focus ((GtkWidget* )pers->perspective_widget);
 
 	return bwin;
@@ -751,10 +743,9 @@ connection_busy_cb (BrowserConnection *bcnc, gboolean is_busy, gchar *reason, Br
 		gtk_action_set_sensitive (action, !is_busy);
 	}
 
-	gchar *cncname;
-	cncname = browser_connection_get_long_name (bcnc);
+	const gchar *cncname;
+	cncname = browser_connection_get_name (bcnc);
 	action = gtk_action_group_get_action (bwin->priv->cnc_agroup, cncname);
-	g_free (cncname);
 	if (action)
 		gtk_action_set_sensitive (action, !is_busy);
 }
@@ -764,21 +755,20 @@ static void
 connection_added_cb (G_GNUC_UNUSED BrowserCore *bcore, BrowserConnection *bcnc, BrowserWindow *bwin)
 {
 	GtkAction *action;
-	gchar *cncname;
+	const gchar *cncname;
 	guint mid;
 
 	mid = gtk_ui_manager_new_merge_id (bwin->priv->ui_manager);
-	cncname = browser_connection_get_long_name (bcnc);
+	cncname = browser_connection_get_name (bcnc);
 	action = gtk_action_new (cncname, cncname, NULL, NULL);
 	gtk_action_group_add_action (bwin->priv->cnc_agroup, action);
 	guint *amid = g_new (guint, 1);
 	*amid = mid;
 	g_object_set_data_full (G_OBJECT (action), "mid", amid, g_free);
 	
-	gtk_ui_manager_add_ui (bwin->priv->ui_manager, mid, "/MenuBar/Window/WindowNewOthers/CncList",
+	gtk_ui_manager_add_ui (bwin->priv->ui_manager, mid,  "/MenuBar/Window/WindowNewOthers/CncList",
 			       cncname, cncname,
-			       GTK_UI_MANAGER_AUTO, FALSE);
-	g_free (cncname);
+			       GTK_UI_MANAGER_AUTO, FALSE);	
 	g_signal_connect (action, "activate",
 			  G_CALLBACK (window_new_with_cnc_cb), bwin);
 	g_object_set_data (G_OBJECT (action), "bcnc", bcnc);
@@ -800,12 +790,11 @@ connection_removed_cb (G_GNUC_UNUSED BrowserCore *bcore, BrowserConnection *bcnc
 {
 	GtkAction *action;
 	gchar *path;
-	gchar *cncname;
+	const gchar *cncname;
 	guint *mid;
 
-	cncname = browser_connection_get_long_name (bcnc);
+	cncname = browser_connection_get_name (bcnc);
 	path = g_strdup_printf ("/MenuBar/Window/WindowNewOthers/CncList/%s", cncname);
-	g_free (cncname);
 	action = gtk_ui_manager_get_action (bwin->priv->ui_manager, path);
 	g_free (path);
 	g_assert (action);
@@ -996,13 +985,8 @@ static gboolean
 fullscreen_motion_notify_cb (GtkWidget *widget, GdkEventMotion *event, G_GNUC_UNUSED gpointer user_data)
 {
 	BrowserWindow *bwin = BROWSER_WINDOW (widget);
-#if GTK_CHECK_VERSION(2,14,0)
 	if (gtk_widget_get_window (widget) != event->window)
 		return FALSE;
-#else
-	if (widget->window != event->window)
-		return FALSE;
-#endif
 
 	if (event->y < BWIN_WINDOW_FULLSCREEN_POPUP_THRESHOLD) {
 		gtk_widget_show (bwin->priv->toolbar);
@@ -1086,7 +1070,7 @@ window_fullscreen_cb (GtkToggleAction *action, BrowserWindow *bwin)
 static gboolean
 key_press_event (GtkWidget *widget, GdkEventKey *event)
 {
-	if ((event->keyval == GDK_Escape) &&
+	if ((event->keyval == GDK_KEY_Escape) &&
 	    browser_window_is_fullscreen (BROWSER_WINDOW (widget))) {
 		browser_window_set_fullscreen (BROWSER_WINDOW (widget), FALSE);
 		return TRUE;
@@ -1132,7 +1116,6 @@ window_state_event (GtkWidget *widget, GdkEventWindowState *event)
 		else
 			gtk_widget_show (wid);
 		
-		gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (bwin->priv->statusbar), !fullscreen);
 		g_signal_emit (G_OBJECT (bwin), browser_window_signals[FULLSCREEN_CHANGED], 0, fullscreen);
         }
 	return FALSE;
@@ -1313,7 +1296,7 @@ browser_window_get_connection (BrowserWindow *bwin)
 /*
  * perspective_data_new
  * @bwin: a #BrowserWindow in which the perspective will be
- * @factory: (allow-none): a #BrowserPerspectiveFactory, or %NULL
+ * @factory: a #BrowserPerspectiveFactory, or %NULL
  *
  * Creates a new #PerspectiveData structure, it increases @bcnc's reference count.
  *
@@ -1449,21 +1432,20 @@ browser_window_show_notice_printf (BrowserWindow *bwin, GtkMessageType type, con
 }
 
 
-#if GTK_CHECK_VERSION (2,18,0)
 static void
 info_bar_response_cb (GtkInfoBar *ibar, G_GNUC_UNUSED gint response, BrowserWindow *bwin)
 {
 	bwin->priv->notif_widgets = g_slist_remove (bwin->priv->notif_widgets, ibar);	
 	gtk_widget_destroy ((GtkWidget*) ibar);
 }
-#endif
 
 /* hash table to remain which context notices have to be hidden: key=context, value=GINT_TO_POINTER (1) */
 static GHashTable *hidden_contexts = NULL;
 static void
 hidden_contexts_foreach_save (const gchar *context, G_GNUC_UNUSED gint value, xmlNodePtr root)
 {
-	xmlNewChild (root, NULL, BAD_CAST "hide-notice", BAD_CAST context);
+	xmlNodePtr node;
+	node = xmlNewChild (root, NULL, BAD_CAST "hide-notice", BAD_CAST context);
 }
 
 static void
@@ -1593,7 +1575,6 @@ browser_window_show_notice (BrowserWindow *bwin, GtkMessageType type, const gcha
 					       (GClosureNotify) g_free, 0);
 		}
 
-#if GTK_CHECK_VERSION (2,18,0)
 		/* use a GtkInfoBar */
 		GtkWidget *ibar, *content_area, *label;
 		
@@ -1626,21 +1607,6 @@ browser_window_show_notice (BrowserWindow *bwin, GtkMessageType type, const gcha
 									 bwin->priv->notif_widgets);
 		}
 		gtk_widget_show (ibar);
-#else
-		/* create the error message dialog */
-		GtkWidget *dialog;
-		dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW (bwin),
-							     GTK_DIALOG_DESTROY_WITH_PARENT |
-							     GTK_DIALOG_MODAL, GTK_MESSAGE_INFO,
-							     GTK_BUTTONS_CLOSE,
-							     "<span weight=\"bold\">%s</span>\n%s", _("Note:"), text);
-		if (cb)
-			gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), cb, FALSE, FALSE, 10);
-	
-		gtk_widget_show_all (dialog);
-		gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (dialog);
-#endif
 	}
 }
 
@@ -1649,8 +1615,8 @@ browser_window_show_notice (BrowserWindow *bwin, GtkMessageType type, const gcha
  * browser_window_customize_perspective_ui
  * @bwin: a #BrowserWindow
  * @bpers: the #BrowserPerspective concerned
- * @actions_group: (allow-none): a #GtkActionGroup object, or %NULL
- * @ui_info: (allow-none): a merge UI string, or %NULL. See gtk_ui_manager_add_ui_from_string()
+ * @actions_group: a #GtkActionGroup object, or %NULL
+ * @ui_info: a merge UI string, or %NULL. See gtk_ui_manager_add_ui_from_string()
  *
  * Customizes a UI specific to the @bpers perspective. Any
  * previous customization is removed, replaced by the new requested one.
