@@ -318,7 +318,7 @@ cloud_object_selected_cb (G_GNUC_UNUSED ObjectsCloud *ocloud, G_GNUC_UNUSED Obje
 
 /**
  * browser_canvas_db_relations_new
- * @mstruct: (allow-none): a #GdaMetaStruct object, or %NULL
+ * @mstruct: a #GdaMetaStruct object, or %NULL
  *
  * Creates a new canvas widget to display the relations between the database's tables.
  *
@@ -402,7 +402,7 @@ canvas_entity_popup_func (BrowserCanvasTable *ce)
 }
 
 static void
-popup_func_declare_fk_cb (G_GNUC_UNUSED GtkMenuItem *mitem, BrowserCanvasTable *ce)
+popup_func_declare_fk_cb (GtkMenuItem *mitem, BrowserCanvasTable *ce)
 {
 	GtkWidget *dlg, *parent;
 	GdaMetaStruct *mstruct;
@@ -497,11 +497,12 @@ popup_func_add_depend_cb (G_GNUC_UNUSED GtkMenuItem *mitem, BrowserCanvasTable *
 		if (g_hash_table_lookup (dbrel->priv->hash_tables, fk->depend_on))
 			continue;
 
+		BrowserCanvasTable *new_item;
 		GValue *v1, *v2, *v3;
 		g_value_set_string ((v1 = gda_value_new (G_TYPE_STRING)), fk->depend_on->obj_catalog);
 		g_value_set_string ((v2 = gda_value_new (G_TYPE_STRING)), fk->depend_on->obj_schema);
 		g_value_set_string ((v3 = gda_value_new (G_TYPE_STRING)), fk->depend_on->obj_name);
-		browser_canvas_db_relations_add_table (dbrel, v1, v2, v3);
+		new_item = browser_canvas_db_relations_add_table (dbrel, v1, v2, v3);
 		gda_value_free (v1);
 		gda_value_free (v2);
 		gda_value_free (v3);
@@ -537,12 +538,12 @@ popup_func_add_ref_cb (G_GNUC_UNUSED GtkMenuItem *mitem, BrowserCanvasTable *ce)
 				continue;
 			if (g_hash_table_lookup (dbrel->priv->hash_tables, fkdbo))
 				continue;
-
+			BrowserCanvasTable *new_item;
 			GValue *v1, *v2, *v3;
 			g_value_set_string ((v1 = gda_value_new (G_TYPE_STRING)), fkdbo->obj_catalog);
 			g_value_set_string ((v2 = gda_value_new (G_TYPE_STRING)), fkdbo->obj_schema);
 			g_value_set_string ((v3 = gda_value_new (G_TYPE_STRING)), fkdbo->obj_name);
-			browser_canvas_db_relations_add_table (dbrel, v1, v2, v3);
+			new_item = browser_canvas_db_relations_add_table (dbrel, v1, v2, v3);
 			gda_value_free (v1);
 			gda_value_free (v2);
 			gda_value_free (v3);
@@ -826,7 +827,7 @@ popup_add_table_cb (G_GNUC_UNUSED GtkMenuItem *mitem, BrowserCanvasDbRelations *
 		GtkWidget *vbox, *cloud, *find, *dcontents;
 		dbrels->priv->add_dialog = gtk_dialog_new_with_buttons (_("Select tables to add to diagram"),
 									(GtkWindow*) gtk_widget_get_toplevel ((GtkWidget*) dbrels),
-									GTK_DIALOG_NO_SEPARATOR,
+									0,
 									NULL);
 		g_signal_connect (dbrels->priv->add_dialog, "close",
 				  G_CALLBACK (gtk_widget_hide), NULL);
@@ -837,11 +838,7 @@ popup_add_table_cb (G_GNUC_UNUSED GtkMenuItem *mitem, BrowserCanvasDbRelations *
 		g_object_set_data (G_OBJECT (dbrels->priv->add_dialog), "__canvas", dbrels);
 
 		vbox = gtk_vbox_new (FALSE, 0);
-#if GTK_CHECK_VERSION(2,18,0)
 		dcontents = gtk_dialog_get_content_area (GTK_DIALOG (dbrels->priv->add_dialog));
-#else
-		dcontents = GTK_DIALOG (dbrels->priv->add_dialog)->vbox;
-#endif
 		gtk_container_add (GTK_CONTAINER (dcontents), vbox);
 		
 		cloud = objects_cloud_new (dbrels->priv->mstruct, OBJECTS_CLOUD_TYPE_TABLE);
@@ -881,8 +878,8 @@ browser_canvas_db_relations_get_table_item  (BrowserCanvasDbRelations *canvas, G
 /**
  * browser_canvas_db_relations_add_table
  * @canvas: a #BrowserCanvasDbRelations canvas
- * @table_catalog: (allow-none): the catalog in which the table is, or %NULL
- * @table_schema: (allow-none): the schema in which the table is, or %NULL
+ * @table_catalog: the catalog in which the table is, or %NULL
+ * @table_schema: the schema in which the table is, or %NULL
  * @table_name: the table's name
  *
  * Add a table to @canvas.
