@@ -204,13 +204,9 @@ create_layout (ConnectionBindingProperties *cprop)
 	gchar *str;
 	GtkWidget *dcontents;
 
-#if GTK_CHECK_VERSION(2,18,0)
 	dcontents = gtk_dialog_get_content_area (GTK_DIALOG (cprop));
-#else
-	dcontents = GTK_DIALOG (cprop)->vbox;
-#endif
-
 	gtk_container_set_border_width (GTK_CONTAINER (dcontents), 10);
+
 	str = g_strdup_printf ("<b>%s:</b>\n<small>%s</small>",
 			       _("Virtual connection's properties"),
 			       _("The virtual connection you are about to define can bind tables "
