@@ -168,7 +168,7 @@ schema_browser_perspective_new (BrowserWindow *bwin)
 				  browser_make_tab_label_with_stock (_("Index"), GTK_STOCK_ABOUT, FALSE,
 								     NULL));
 	gtk_notebook_set_tab_reorderable (GTK_NOTEBOOK (nb), wid, TRUE);
-	gtk_notebook_set_group (GTK_NOTEBOOK (nb), bcnc);
+	gtk_notebook_set_group_name (GTK_NOTEBOOK (nb), "schema-browser");
 
 	gtk_notebook_set_menu_label (GTK_NOTEBOOK (nb), wid,
 				     browser_make_tab_label_with_stock (_("Index"), GTK_STOCK_ABOUT, FALSE,
@@ -319,11 +319,13 @@ static const gchar *ui_actions_info =
 	"    <menu name='Display' action='Display'>"
 	"      <menuitem name='SchemaBrowserFavoritesShow' action='SchemaBrowserFavoritesShow'/>"
         "    </menu>"
+#ifdef HAVE_GOOCANVAS
         "    <placeholder name='MenuExtension'>"
         "      <menu name='Schema' action='Schema'>"
         "        <menuitem name='NewDiagram' action= 'NewDiagram'/>"
         "      </menu>"
         "    </placeholder>"
+#endif
         "  </menubar>"
         "</ui>";
 
