@@ -842,11 +842,7 @@ visibility_notify_event (GtkWidget *text_view, G_GNUC_UNUSED GdkEventVisibility
 {
 	gint wx, wy, bx, by;
 	
-#if GTK_CHECK_VERSION(2,18,0)
 	gdk_window_get_pointer (gtk_widget_get_window (text_view), &wx, &wy, NULL);
-#else
-	gdk_window_get_pointer (text_view->window, &wx, &wy, NULL);
-#endif
 	
 	gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (text_view), 
 					       GTK_TEXT_WINDOW_WIDGET,
@@ -871,11 +867,7 @@ motion_notify_event (GtkWidget *text_view, GdkEventMotion *event, TableColumns *
 	
 	set_cursor_if_appropriate (GTK_TEXT_VIEW (text_view), x, y, tcolumns);
 
-#if GTK_CHECK_VERSION(2,18,0)
 	gdk_window_get_pointer (gtk_widget_get_window (text_view), NULL, NULL, NULL);
-#else
-	gdk_window_get_pointer (text_view->window, NULL, NULL, NULL);
-#endif
 
 	return FALSE;
 }
@@ -1033,8 +1025,8 @@ key_press_event (GtkWidget *text_view, GdkEventKey *event, TableColumns *tcolumn
 	GtkTextBuffer *buffer;
 	
 	switch (event->keyval) {
-	case GDK_Return: 
-	case GDK_KP_Enter:
+	case GDK_KEY_Return: 
+	case GDK_KEY_KP_Enter:
 		buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (text_view));
 		gtk_text_buffer_get_iter_at_mark (buffer, &iter, 
 						  gtk_text_buffer_get_insert (buffer));
